#!/bin/ksh

#
# The run_common_bad_syntax function tests the following common syntax errors for asadmin *jbi* 
# commands:
# C1. unexpected -- flag
# C2. unexpected - flag
# C3. --echo invalid value (not true or false)
# C4. -e invalid value (not true or false)
# C5. --interactive invalid value (not true or false)
# C6. -I invalid value (not true or false)
# C7. --terse invalid value (not true or false)
# C8. -t invalid value (not true or false)
# C9. --secure invalid value (not true or false)
# C10. -s invalid value (not true or false)
# C11. --port non-numeric value 
# C12. --port incorrect value 
# C13. -p non-numeric value
# C14. -p incorrect value
# C15. --host empty value
# C16. --host incorrect value  
# C17. -H empty value
# C18. -H incorrect value
# C19. --user empty value
# C20. --user incorrect value  
# C21. -u empty value
# C22. -u incorrect value
# C23. --passwordfile file does not exist
# C24. --passwordfile file does not contain password
# C25. --passwordfile file is not correct for user
# C26. --target is empty value
# C27. --target is not valid
#
# Only for install-jbi* or deploy-jbi* commands:
# I1. --upload is not valid (not true or false) 
#
# Only for uninstall-jbi-component or undeploy-jbi* commands:
# U1. --force invalid value (not true or false)
# U2. --force invalid value (not true or false)
# 
# U3. --keeparchive invalid value (not true or false)
#
# Only for list-jbi* commands
# L1. Unexpected operand
# Only for list commands for lifecycles
# L2. --lifecyclestate invalid value
# Only for components
# L3. --libraryname not recognized
# L4. --assemblyname not recognized
# Only for list commands for libraries and service assemblies
# L5. --componentname not recognized

# argument ${1} is command name
# argument ${2} is operand, if required
run_common_bad_syntax_tests()
{
    curr_cmd=${1}
    curr_operand=${2}
    # C1. unexpected -- flag
    echo_error "C1. unexpected flag with --" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --bogus="true" ${curr_operand} >> ${deterministic_output} 2>&1

    # C2. unexpected - flag
    echo_error "C2. unexpected flag with -" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -bogus="true" ${curr_operand} >> ${deterministic_output} 2>&1

    # C3. --echo invalid value (not true or false)
    echo_error "C3. --echo invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --echo="bogus" ${curr_operand} >> ${deterministic_output} 2>&1
    # C4. -e invalid value (not true or false)
    echo_error "C4. -e invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -e="5" ${curr_operand} >> ${deterministic_output} 2>&1

    # C5. --interactive invalid value (not true or false)
    echo_error "C5. --interactive invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --interactive="silly" ${curr_operand} >> ${deterministic_output} 2>&1
    # C6. -I invalid value (not true or false)
    echo_error "C6. -I invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -I="5" ${curr_operand} >> ${deterministic_output} 2>&1

    # C7. --terse invalid value (not true or false)
    echo_error "C7. --terse invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --terse="silly" ${curr_operand} >> ${deterministic_output} 2>&1
    # C8. -t invalid value (not true or false) 
    echo_error "C8. -t invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -t="5" ${curr_operand} >> ${deterministic_output} 2>&1

    # C9. --secure invalid value (not true or false)
    echo_error "C9. --secure invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --secure="bogus" ${curr_operand} >> ${deterministic_output} 2>&1
    # C10. -s invalid value (not true or false)
    echo_error "C10. -s invalid value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -s="5" ${curr_operand} >> ${deterministic_output} 2>&1

    # C11. --port non-numeric value 
    echo_error "C11. non-numeric port value --port " 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --port="grouperfishbogus" ${curr_operand} >> ${deterministic_output} 2>&1
    # C12. --port incorrect value 
    echo_error "C12. incorrect port value --port " 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --port="5" ${curr_operand} >> ${deterministic_output} 2>&1
    # C13. -p non-numeric value
    echo_error "C13. non-numeric port value -p" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -p="grouperfishbogus" ${curr_operand} >> ${deterministic_output} 2>&1
    # C14. -p incorrect value
    echo_error "C14. incorrect port value -p " 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -p="5" ${curr_operand} >> ${deterministic_output} 2>&1

    # C15. --host empty value
    echo_error "C15. empty host value --host" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --host="" ${curr_operand} >> ${deterministic_output} 2>&1
    # C16. --host incorrect value  
    echo_error "C16. incorrect host value --host" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --host="whimsicalbogus" ${curr_operand} >> ${deterministic_output} 2>&1
    # C17. -H empty value
    echo_error "C17. -H empty host value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -H="" ${curr_operand} >> ${deterministic_output} 2>&1
    # C18. -H incorrect value
    echo_error "C18. -H incorrect host value" 
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -H="sillybogusunlikelymachinename" ${curr_operand} >> ${deterministic_output} 2>&1

    # C19. --user empty value
    echo_error "C19. empty value --user"
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --user="" ${curr_operand} >> ${deterministic_output} 2>&1
    # C20. --user incorrect value  
    echo_error "C20. unknown user --user"
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --user="grouperfishbogus" ${curr_operand} >> ${deterministic_output} 2>&1
    # C21. -u empty value
    echo_error "C21. empty value -u"
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -u="" ${curr_operand} >> ${deterministic_output} 2>&1
    # C22. -u incorrect value
    echo_error "C22. unknown user -u"
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -u="grouperfishbogus" ${curr_operand} >> ${deterministic_output} 2>&1

    # C23. --passwordfile file does not exist
    echo_error "C23. unavailable passwordfile --passwordfile"
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --passwordfile="grouperfishbogus" ${curr_operand} >> ${deterministic_output} 2>&1
    # C24. --passwordfile file does not contain password
    echo_error "C24. empty passwordfile --passwordfile" 
    echo "" >> emptypasswordfile
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --passwordfile="emptypasswordfile" ${curr_operand} >> ${deterministic_output} 2>&1
    # C25. --passwordfile file is not correct for user
    echo_error "C25. invalid password in file --passwordfile" 
    echo "bogus_password" >> bogus_pw_file
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --passwordfile="bogus_pw_file" ${curr_operand} >> ${deterministic_output} 2>&1

    # C26. --target is empty value
    echo_error "C26. empty value for --target"
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --target="" ${curr_operand} >> ${deterministic_output} 2>&1
    # C27. --target is not valid
    echo_error "C27. invalid target name --target"
    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --target="grouperfishbogus" ${curr_operand} >> ${deterministic_output} 2>&1

    # Only for install-jbi* or deploy-jbi* commands:
    if [ ${curr_cmd} = "install-jbi-component" -o ${curr_cmd} = "install-jbi-shared-library" -o ${curr_cmd} = "deploy-jbi-service-assembly" ]
    then
        # I1. --upload invalid value (not true or false)
	echo_error "I1. --upload invalid value" 
	${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --upload="bogus" ${curr_operand} >> ${deterministic_output} 2>&1
    fi


    # Only for uninstall-jbi* or undeploy-jbi* commands:
    un_test=${curr_cmd##un*}
    if [ "${un_test}" = "" ]
	then

        # Only for uninstall-jbi-component or undeploy-jbi* commands:
	if [ "${curr_cmd}" = "uninstall-jbi-component" -o "${curr_cmd}" = "undeploy-jbi-service-assembly" ]
	    then 
            # U1. --force invalid value (not true or false)
	    echo_error "U1. --force invalid value" 
	    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --force="bogus" ${curr_operand} >> ${deterministic_output} 2>&1
            # U2. -F invalid value (not true or false)
	    echo_error "U2. -F invalid value" 
	    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} -F="bogus" ${curr_operand} >> ${deterministic_output} 2>&1
	fi

        # U3. --keeparchive invalid value (not true or false)
	echo_error "U3. --keeparchive invalid value" 
	${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --keeparchive="bogus" ${curr_operand} >> ${deterministic_output} 2>&1
    fi

    # Only for list-jbi* commands
    list_test=${curr_cmd##list-jbi*}
    if [ "${list_test}" = "" ]
	then
        # L1. Unexpected operand
        echo_error "L1. Unexpected operand"
	${asadmin_cmd} ${curr_cmd} ${common_cmd_options} "unexpectedOperand" >> ${deterministic_output} 2>&1
	lifecycle=0
	component=0
        environment=0
	case $curr_cmd in
	    list-jbi-binding-components|list-jbi-service-engines)
                lifecycle=1
		component=1
		;;
	    list-jbi-service-assemblies)
                lifecycle=1
		;;
	    list-jbi-application-configurations|list-jbi-application-variables)
                environment=1
		;;
	    list-jbi-shared-libraries)
                ;;
	esac
        # Only for list commands for lifecycles
	if [ $lifecycle -eq 1 ]
	    then
            # L2. --lifecyclestate invalid value
	    echo_error "L2. --lifecyclestate invalid value" 
	    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --lifecyclestate="bogus" >> ${deterministic_output} 2>&1
	fi # if lifecycle
        # Only for components
	if [ $component -eq 1 ]
	    then
            # L3. --libraryname not recognized
	    echo_error "L3. --libraryname not recognized" 
	    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --libraryname="bogus" >> ${deterministic_output} 2>&1
            # L4. --assemblyname not recognized
	    echo_error "L4. --assemblyname not recognized" 
	    ${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --assemblyname="bogus" >> ${deterministic_output} 2>&1
	else
	    if [ $environment -eq 0 ]
		then
            # Only for list commands for libraries and service assemblies
            # L5. --componentname not recognized
		echo_error "L5. --componentname not recognized"
		${asadmin_cmd} ${curr_cmd} ${common_cmd_options} --componentname="bogus" >> ${deterministic_output} 2>&1            
	    fi # if not environment
	fi # if component
    fi # if list
}
	
install_wsdl_library()
{
    ${asadmin_cmd} install-jbi-shared-library ${common_cmd_options} ${wsdl_library_installation_archive} >> ${deterministic_output} 2>&1
    return $?
}

install_wsdl_ext_library()
{
    ${asadmin_cmd} install-jbi-shared-library ${common_cmd_options} ${jbi_component_home_dir}/wsdlextlib.jar >> ${deterministic_output} 2>&1
    return $?
}

install_saxon_library()
{
    ${asadmin_cmd} install-jbi-shared-library ${common_cmd_options} ${jbi_component_home_dir}/saxonlib.jar >> ${deterministic_output} 2>&1
    return $?
}

uninstall_wsdl_ext_library()
{
    ${asadmin_cmd} uninstall-jbi-shared-library ${common_cmd_options} sun-wsdl-ext-library >> ${deterministic_output} 2>&1
    return $?
}

uninstall_saxon_library()
{
    ${asadmin_cmd} uninstall-jbi-shared-library ${common_cmd_options} sun-saxon-library >> ${deterministic_output} 2>&1
    return $?
}

uninstall_wsdl_library()
{
    ${asadmin_cmd} uninstall-jbi-shared-library ${common_cmd_options} sun-wsdl-library >> ${deterministic_output} 2>&1
    return $?
}

install_se()
{
    ${asadmin_cmd} install-jbi-component ${common_cmd_options} ${jbi_component_home_dir}/bpelserviceengine.jar >> ${deterministic_output} 2>&1
    return $?
}

start_se()
{
    ${asadmin_cmd} start-jbi-component ${common_cmd_options} sun-bpel-engine >> ${deterministic_output} 2>&1
    return $?
}

stop_se()
{
    ${asadmin_cmd} stop-jbi-component ${common_cmd_options} sun-bpel-engine >> ${deterministic_output} 2>&1
    return $?
}

shutdown_se()
{
    ${asadmin_cmd} shut-down-jbi-component ${common_cmd_options} sun-bpel-engine >> ${deterministic_output} 2>&1
    return $?
}

uninstall_se()
{
    ${asadmin_cmd} uninstall-jbi-component ${common_cmd_options} sun-bpel-engine >> ${deterministic_output} 2>&1
    return $?
}

install_bc()
{
    ${asadmin_cmd} install-jbi-component ${common_cmd_options} ${ojc_http_binding_installation_archive} >> ${deterministic_output} 2>&1
    return $?
}

start_bc()
{
    ${asadmin_cmd} start-jbi-component ${common_cmd_options} sun-http-binding >> ${deterministic_output} 2>&1
    return $?
}

stop_bc()
{
    ${asadmin_cmd} stop-jbi-component ${common_cmd_options} sun-http-binding >> ${deterministic_output} 2>&1
    return $?
}

shutdown_bc()
{
    ${asadmin_cmd} shut-down-jbi-component ${common_cmd_options} sun-http-binding >> ${deterministic_output} 2>&1
    return $?

}

uninstall_bc()
{
    ${asadmin_cmd} uninstall-jbi-component ${common_cmd_options} sun-http-binding >> ${deterministic_output} 2>&1
    return $?
}

setup_comps_sa_tests()
{
    test_status=0

    install_wsdl_library
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #S1"
	    test_status=1
    fi

    install_wsdl_ext_library
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #S1A"
	    test_status=1
    fi

#    install_saxon_library
#    if [ $? -ne 0 ]
#	then
#        echo "Setting test_status equal to FAIL: failed to install saxon sl"
#	    test_status=1
#    fi

    install_bc
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #S2"
	    test_status=1
    fi

    start_bc
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #S3"
	    test_status=1
    fi

    install_se
    if [ $? -ne 0 ]
	then
	    echo "Setting test_status equal to FAIL: failure point #S4"
    	test_status=1
    fi

    start_bc
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #S5"
	    test_status=1
    fi

    return $test_status
}

remove_comps_sa_tests()
{
    test_status=0

    shutdown_se
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #R1"
	    test_status=1
    fi

    uninstall_se
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #R2"
	    test_status=1
    fi

    shutdown_bc
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #R3"
	    test_status=1
    fi

    uninstall_bc
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #R4"
	    test_status=1
    fi

    uninstall_wsdl_library
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #R5"
	    test_status=1
    fi

    uninstall_wsdl_ext_library
    if [ $? -ne 0 ]
	then
    	echo "Setting test_status equal to FAIL: failure point #32"
	    test_status=1
    fi

#    uninstall_saxon_library
#    if [ $? -ne 0 ]
#	then
#        echo "Setting test_status equal to FAIL: failed to uninstall saxon sl"
#	    test_status=1
#    fi

    return $test_status
}

deploy_sa()
{
    ${asadmin_cmd} deploy-jbi-service-assembly ${common_cmd_options} ${bpel_deploy_file} >> ${deterministic_output} 2>&1
    return $?
}

start_sa()
{
    ${asadmin_cmd} start-jbi-service-assembly ${common_cmd_options} ${bpel_deploy_name} >> ${deterministic_output} 2>&1
    return $?
}

stop_sa()
{
    ${asadmin_cmd} stop-jbi-service-assembly ${common_cmd_options} ${bpel_deploy_name} >> ${deterministic_output} 2>&1
    return $?
}

shutdown_sa()
{
    ${asadmin_cmd} shut-down-jbi-service-assembly ${common_cmd_options} ${bpel_deploy_name} >> ${deterministic_output} 2>&1
    return $?
}

undeploy_sa()
{
    ${asadmin_cmd} undeploy-jbi-service-assembly ${common_cmd_options} ${bpel_deploy_name} >> ${deterministic_output} 2>&1
    return $?
}

