#!/bin/ksh
#set -x
#
# This file contains often-used ksh functions.
#

# echos text with ACTION identifier
echo_action()
{
  print "\nACTION: ${1}" >> ${deterministic_output}
}

# echos text with SETUP identifier
echo_setup()
{
  print "\nSETUP: ${1}" >> ${deterministic_output}
}

# echos text with ERROR identifier
echo_error()
{
  print "\nERROR: ${1}" >> ${deterministic_output}
}

# echos text with CLEANUP identifier
echo_cleanup()
{
  print "\nCLEANUP: ${1}" >> ${deterministic_output}
}

# echos return value
echo_result()
{
  print "\nRETURN VALUE: ${1}" >> ${deterministic_output}
}
# list components
# -v => --terse/-t=false; -t => --terse/-t=true
listcomponents()
{
    case "$1" in 
        -t ) viewl="--terse=true";views="-t=true";;
        -v ) viewl="--terse=false";views="-t=false";;
    default ) viewl=""; views="";;
    esac
    echo_action "list shared libraries" 
    ${asadmin_cmd} list-jbi-shared-libraries ${common_cmd_options} ${viewl} >> ${deterministic_output}
    if [ $? -ne 0 ]
    then
    status=1
    fi
    echo_action "list binding components" 
    ${asadmin_cmd} list-jbi-binding-components ${common_cmd_options} ${views} >> ${deterministic_output}
    if [ $? -ne 0 ]
    then
    status=1
    fi
    echo_action "list service engines" 
    ${asadmin_cmd} list-jbi-service-engines ${common_cmd_options} ${viewl} >> ${deterministic_output}
    if [ $? -ne 0 ]
    then
    status=1
    fi
}

# Writes out the test info.
write_test_info()
{
    echo "Test Started   = `date`"
    echo "Test Base      = ${tonga_test_base_dir}"
    echo "Suite Name     = ${tonga_suite_name}"
    echo "Suite Work Dir = ${tonga_suite_work_dir}"
    echo "Test Work Dir  = ${tonga_test_work_dir}"
}

# list service assemblies based on states; $1 is target
list_service_assemblies_by_states()
{
    if [ "X${1}" = "X" ]
	then
	target=server
	else
	target=${1}
    fi
    list_command="${asadmin_cmd} list-jbi-service-assemblies ${common_cmd_options} --target ${target}"
    echo_action "list service assemblies on ${target}" 
    ${list_command} >> ${deterministic_output}
    echo_action "list service assemblies on ${target} in different states:" >> ${deterministic_output}
    echo_action "  lifecyclestate shutdown"
    ${list_command} --lifecyclestate shutdown >> ${deterministic_output}
    echo_action "  lifecyclestate started" 
    ${list_command} --lifecyclestate started >> ${deterministic_output}
    echo_action "  lifecyclestate stopped" 
    ${list_command} --lifecyclestate stopped >> ${deterministic_output}
}

# list service assemblies that configure the specified component -- component name must be specified
list_service_assemblies_for_component()
{
    list_command="${asadmin_cmd} list-jbi-service-assemblies ${common_cmd_options}"

    echo_action "list service assemblies that configure the specified component: ${1}" 
    ${list_command} --componentname ${1} >> ${deterministic_output}
}

# list components configured by the specified service assembly 
list_components_for_service_assembly()
{
    list_bc_command="${asadmin_cmd} list-jbi-binding-components ${common_cmd_options}"
    list_se_command="${asadmin_cmd} list-jbi-service-engines ${common_cmd_options}"

    echo_action "list binding components configured by service assembly ${1}"
    ${list_bc_command} --assemblyname ${1} >> ${deterministic_output}

    echo_action "list service engines configured by service assembly ${1}"
    ${list_se_command} --assemblyname ${1} >> ${deterministic_output}
}

# list components dependent on the specified shared library;
list_components_using_library()
{
    list_bc_command="${asadmin_cmd} list-jbi-binding-components ${common_cmd_options}"
    list_se_command="${asadmin_cmd} list-jbi-service-engines ${common_cmd_options}"

    echo_action "list binding components using ${1}"
    ${list_bc_command} --libraryname ${1} >> ${deterministic_output}

    echo_action "list service engines using ${1}"
    ${list_se_command} --libraryname ${1} >> ${deterministic_output}

}

# list binding components by state; $1 is target 
list_bcs_by_state()
{
    if [ "X${1}" = "X" ]
	then
	target=server
	else
	target=${1}
    fi
    list_bc_command="${asadmin_cmd} list-jbi-binding-components ${common_cmd_options} --target ${target}"

    echo_action "list binding components on ${target}" 
    ${list_bc_command} >> ${deterministic_output}
    echo_action "list binding components on ${target} in different states:" >> ${deterministic_output}
    echo_action "  lifecyclestate shutdown"
    ${list_bc_command} --lifecyclestate shutdown >> ${deterministic_output}
    echo_action "  lifecyclestate started" 
    ${list_bc_command} --lifecyclestate started >> ${deterministic_output}
    echo_action "  lifecyclestate stopped" 
    ${list_bc_command} --lifecyclestate stopped >> ${deterministic_output}
}

# list service engines by state; $1 is target
list_ses_by_state()
{
    if [ "X${target}" = "X" ]
	then
	target=server
	else
	target=${target}
    fi
    list_se_command="${asadmin_cmd} list-jbi-service-engines ${common_cmd_options} --target ${target}"

    echo_action "list service engines on ${target}" 
    ${list_se_command} >> ${deterministic_output}
    echo_action "list service engines on ${target} in different states:" >> ${deterministic_output}
    echo_action "  lifecyclestate shutdown"
    ${list_se_command} --lifecyclestate shutdown >> ${deterministic_output}
    echo_action "  lifecyclestate started" 
    ${list_se_command} --lifecyclestate started >> ${deterministic_output}
    echo_action "  lifecyclestate stopped" 
    ${list_se_command} --lifecyclestate stopped >> ${deterministic_output}
}


# show help text for command
# param 1 is for command
show_help()
{
    echo_action "request help information using --help option" 
    ${asadmin_cmd} ${1} --help >> ${deterministic_output}
    
    echo_action "request help information using --help option with other common options" 
    ${asadmin_cmd} ${1} --help ${common_options} >> ${deterministic_output}
    
}

